@@ -10,12 +10,10 @@ use imp::fd::AsFd;
 #[cfg(any(linux_raw, all(libc, any(target_os = "android", target_os = "linux"))))]
 #[inline]
 pub fn sendfile<OutFd: AsFd, InFd: AsFd>(
-    out_fd: &OutFd,
-    in_fd: &InFd,
+    out_fd: OutFd,
+    in_fd: InFd,
     offset: Option<&mut u64>,
     count: usize,
 ) -> io::Result<usize> {
-    let out_fd = out_fd.as_fd();
-    let in_fd = in_fd.as_fd();
-    imp::fs::syscalls::sendfile(out_fd, in_fd, offset, count)
+    imp::fs::syscalls::sendfile(out_fd.as_fd(), in_fd.as_fd(), offset, count)
 }
