@@ -35,9 +35,12 @@ pub enum MembarrierCommand {
     RegisterPrivateExpeditedRseq = 256,
 }
 
-/// A resource value for use with [`getrlimit`].
+/// A resource value for use with [`getrlimit`], [`setrlimit`], and
+/// [`prlimit`].
 ///
 /// [`getrlimit`]: crate::process::getrlimit
+/// [`setrlimit`]: crate::process::setrlimit
+/// [`prlimit`]: crate::process::prlimit
 #[cfg(not(any(target_os = "fuchsia", target_os = "redox", target_os = "wasi")))]
 #[derive(Copy, Clone, Debug, Eq, PartialEq)]
 #[repr(i32)]
@@ -191,6 +194,10 @@ pub enum Signal {
         target_os = "macos",
         target_os = "netbsd",
         target_os = "openbsd",
+        all(
+            any(target_os = "android", target_os = "linux"),
+            any(target_arch = "mips", target_arch = "mips64")
+        )
     )))]
     Stkflt = c::SIGSTKFLT,
     /// `SIGCHLD`
@@ -264,6 +271,10 @@ impl Signal {
                 target_os = "macos",
                 target_os = "netbsd",
                 target_os = "openbsd",
+                all(
+                    any(target_os = "android", target_os = "linux"),
+                    any(target_arch = "mips", target_arch = "mips64")
+                )
             )))]
             c::SIGSTKFLT => Some(Self::Stkflt),
             c::SIGCHLD => Some(Self::Child),
