@@ -3,12 +3,12 @@
 //! dca3f1b786efd27be3b325ed1e01e247aa589c3b.
 
 #![allow(unsafe_code)]
-#![allow(missing_docs)]
 
 use super::c;
 use core::marker::PhantomData;
 use core::slice;
 
+/// <https://doc.rust-lang.org/nightly/std/io/struct.IoSlice.html>
 #[derive(Copy, Clone)]
 #[repr(transparent)]
 pub struct IoSlice<'a> {
@@ -17,6 +17,7 @@ pub struct IoSlice<'a> {
 }
 
 impl<'a> IoSlice<'a> {
+    /// <https://doc.rust-lang.org/nightly/std/io/struct.IoSlice.html#method.new>
     #[inline]
     pub fn new(buf: &'a [u8]) -> IoSlice<'a> {
         IoSlice {
@@ -28,6 +29,7 @@ impl<'a> IoSlice<'a> {
         }
     }
 
+    /// <https://doc.rust-lang.org/nightly/std/io/struct.IoSlice.html#method.advance>
     #[inline]
     pub fn advance(&mut self, n: usize) {
         if self.vec.iov_len < n as u64 {
@@ -40,12 +42,14 @@ impl<'a> IoSlice<'a> {
         }
     }
 
+    /// <https://doc.rust-lang.org/nightly/std/io/struct.IoSlice.html#method.as_slice>
     #[inline]
     pub fn as_slice(&self) -> &[u8] {
         unsafe { slice::from_raw_parts(self.vec.iov_base as *mut u8, self.vec.iov_len as usize) }
     }
 }
 
+/// <https://doc.rust-lang.org/nightly/std/io/struct.IoSliceMut.html>
 #[repr(transparent)]
 pub struct IoSliceMut<'a> {
     vec: c::iovec,
@@ -53,6 +57,7 @@ pub struct IoSliceMut<'a> {
 }
 
 impl<'a> IoSliceMut<'a> {
+    /// <https://doc.rust-lang.org/nightly/std/io/struct.IoSliceMut.html#method.new>
     #[inline]
     pub fn new(buf: &'a mut [u8]) -> IoSliceMut<'a> {
         IoSliceMut {
@@ -64,6 +69,7 @@ impl<'a> IoSliceMut<'a> {
         }
     }
 
+    /// <https://doc.rust-lang.org/nightly/std/io/struct.IoSliceMut.html#method.advance>
     #[inline]
     pub fn advance(&mut self, n: usize) {
         if self.vec.iov_len < n as u64 {
@@ -76,11 +82,13 @@ impl<'a> IoSliceMut<'a> {
         }
     }
 
+    /// <https://doc.rust-lang.org/nightly/std/io/struct.IoSliceMut.html#method.as_slice>
     #[inline]
     pub fn as_slice(&self) -> &[u8] {
         unsafe { slice::from_raw_parts(self.vec.iov_base as *mut u8, self.vec.iov_len as usize) }
     }
 
+    /// <https://doc.rust-lang.org/nightly/std/io/struct.IoSliceMut.html#method.as_slice_mut>
     #[inline]
     pub fn as_mut_slice(&mut self) -> &mut [u8] {
         unsafe {
