@@ -1,6 +1,6 @@
 #[cfg(any(target_os = "android", target_os = "linux"))]
 use rustix::process::linux_hwcap;
-use rustix::process::page_size;
+use rustix::process::{clock_ticks_per_second, page_size};
 
 #[test]
 fn test_page_size() {
@@ -11,6 +11,13 @@ fn test_page_size() {
     assert_eq!(size, unsafe { libc::sysconf(libc::_SC_PAGESIZE) as usize });
 }
 
+#[test]
+fn test_clock_ticks_per_second() {
+    let size = clock_ticks_per_second();
+    assert_ne!(size, 0);
+    assert_eq!(size, unsafe { libc::sysconf(libc::_SC_CLK_TCK) as u64 });
+}
+
 #[test]
 #[cfg(any(target_os = "android", target_os = "linux"))]
 fn test_linux_hwcap() {
